@@ -241,7 +241,8 @@
    :jar-exclusions [#"^\." (re-pattern (Pattern/quote (str File/separator ".")))]
    :eval-in :default
    :offline? (not (nil? (System/getenv "LEIN_OFFLINE")))
-   :uberjar-exclusions [#"(?i)^META-INF/[^/]*\.(SF|RSA|DSA)$"]
+   :uberjar-exclusions [#"(?i)^META-INF/[^/]*\.(SF|RSA|DSA)$"
+                        #"^module-info.class$"]
    :uberjar-merge-with {"META-INF/plexus/components.xml"
                         'leiningen.uberjar/components-merger,
                         "data_readers.clj"
@@ -557,7 +558,7 @@
                 :test-selectors {:default (with-meta '(constantly true)
                                             {:displace true})}
                 ;; bump deps in leiningen's own project.clj with these
-                :dependencies '[^:displace [nrepl/nrepl "0.8.3"
+                :dependencies '[^:displace [nrepl/nrepl "0.9.0"
                                             :exclusions [org.clojure/clojure]]
                                 ^:displace [org.nrepl/incomplete "0.1.0"
                                             :exclusions [org.clojure/clojure]]]
@@ -700,7 +701,7 @@
                (not (System/getenv "LEIN_SUPPRESS_USER_LEVEL_REPO_WARNINGS")))
       (warn-once ":repositories detected in user-level profiles!"
                  (vec (map first repo-profiles)) "\nSee"
-                 "https://github.com/technomancy/leiningen/wiki/Repeatability"))))
+                 "https://codeberg.org/leiningen/leiningen/wiki/Repeatability"))))
 
 (defn- warn-user-profile [root profiles]
   (when (and root (contains? profiles :user))
@@ -902,11 +903,7 @@
     profile))
 
 (defn- apply-profile-meta [default-meta profile]
-  (cond-> profile
-    (or (map? profile)
-        (composite-profile? profile))
-    (vary-meta (fn [m] (merge default-meta m)))
-    (map? profile) set-dependencies-pom-scope))
+  (vary-meta profile (fn [m] (merge default-meta m))))
 
 (defn project-with-profiles
   ([project profiles]
@@ -930,14 +927,19 @@
         include-profiles-meta (->> (expand-profiles-with-meta
                                     project include-profiles)
                                    (utils/last-distinct-by first))
-        include-profiles (map first include-profiles-meta)
+        effective-include-profiles (map first include-profiles-meta)
         exclude-profiles (utils/last-distinct (expand-profiles project exclude-profiles))
         profile-map (apply dissoc (:profiles (meta project)) exclude-profiles)
-        profiles (map (partial lookup-profile profile-map) include-profiles)
-        normalized-profiles (map normalize-values profiles)]
+        profiles (for [profile-name effective-include-profiles]
+                   (let [profile (lookup-profile profile-map profile-name)
+                         metas (into {} include-profiles-meta)
+                         profile-meta (metas profile-name)]
+                     (-> (vary-meta profile merge profile-meta)
+                         set-dependencies-pom-scope
+                         normalize-values)))]
     (-> project
-        (apply-profiles normalized-profiles)
-        (profile-scope-target-path include-profiles)
+        (apply-profiles profiles)
+        (profile-scope-target-path effective-include-profiles)
         (target-path-subdirs :compile-path)
         (target-path-subdirs :native-path)
         (absolutize-paths)
@@ -985,6 +987,10 @@
   (let [{:keys [included-profiles excluded-profiles]} (meta project)
         profiles (expand-profiles project profiles)]
     (set-profiles project
+                  ;; we need un-expanded profiles here because if :dev was
+                  ;; a composite profile that included :foo, we need to start
+                  ;; from :dev in order to ensure :foo's dependencies have
+                  ;; test scope in the pom.
                   (remove (set profiles) included-profiles)
                   (concat excluded-profiles profiles))))
 
