@@ -1,10 +1,10 @@
-(defproject leiningen-core "2.9.8"
-  :url "https://github.com/technomancy/leiningen"
+(defproject leiningen-core "2.9.10"
+  :url "https://codeberg.org/leiningen/leiningen"
   :license {:name "Eclipse Public License"
             :url "http://www.eclipse.org/legal/epl-v10.html"}
   :description "Library for core functionality of Leiningen."
   ;; If you update these, update resources/leiningen/bootclasspath-deps.clj too
-  :dependencies [[org.clojure/clojure "1.10.3"]
+  :dependencies [[org.clojure/clojure "1.11.1"]
                  [timofreiberg/bultitude "0.3.0"
                   :exclusions [org.clojure/clojure]]
                  [org.flatland/classlojure "0.7.1"]
